# iq_readout

[![Documentation Status](https://readthedocs.org/projects/iq-readout/badge/?version=latest)](https://iq-readout.readthedocs.io/en/latest/?badge=latest)
![example workflow](https://github.com/MarcSerraPeralta/iq_readout/actions/workflows/actions.yaml/badge.svg)

Classifiers for the IQ readout data from superconducting qubits.

For more information, check the [documentation website](https://iq-readout.readthedocs.io/en/latest/index.html).

## Installation

As the package has not been published on PyPi yet, it CANNOT be installed directly using pip. 
One can use the following commands to install the package:

```
git clone git@github.com:MarcSerraPeralta/iq_readout.git
pip install iq_readout/
```
